@@ -3,6 +3,7 @@ Module for integrating with PeakRDL. This module is not intended to be used dire
 refer to the PeakRDL documentation
 """
 from typing import TYPE_CHECKING
+import pathlib
 
 from .exporter import PythonExporter
 
@@ -28,7 +29,9 @@ class Exporter:
 
         """
         arg_group.add_argument('--autoformat', action='store_true',
-                        help='use autopep8 on generated code')
+                                help='use autopep8 on generated code')
+        arg_group.add_argument('--user_template_dir', action='store', type=pathlib.Path,
+                               help='directory of user templates to override the default ones')
 
     def do_export(self, top_node: 'AddrmapNode', options: 'argparse.Namespace') -> None:
         """
@@ -41,8 +44,11 @@ class Exporter:
         Returns:
 
         """
+        if options.user_template_dir is None:
+            peakrdl_exporter = PythonExporter()
+        else:
+            peakrdl_exporter = PythonExporter(user_template_dir=options.user_template_dir)
 
-        peakrdl_exporter = PythonExporter()
         peakrdl_exporter.export(
             top_node,
             options.output,
